//
//  PrinterSearchTopView.swift
//  BMS_SwiftUI_Sample_v4_Basic
//
//  THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF
//  ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO
//  THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
//  PARTICULAR PURPOSE.
//
//  Created by Rob Roy
//  Copyright © 2020 Brother Mobile Solutions. All rights reserved.
//

import SwiftUI

struct PrinterSearchTopView: View {
    
    // NOTE: the "xxxSearchResultViews" are designed to be used as "child" views in DIFFERENT situations.
    // * In some cases, the "parent" view may want to display the information provided by these variables.
    //   To do that, it must define the @State variable here, and pass that to these "child" views as a @Binding.
    // * In this TopView, we are NOT (currently) displaying this information.
    //   So, these are essentially "dummy" variables, only needed for the parameter required by the child views.
    @State var wifiIPAddress:String = "Not Used"
    @State var mfiSerialNumber:String = "Not Used"
    @State var bleLocalName:String = "Not Used"
    
    var body: some View {
        List {
            
            //*** WIFI
            NavigationLink(destination: WIFISearchResultView(printersToSearch: SupportedModels.getArrayOfAllSupportedWIFIModels(),
                                                             doSearchOnAppear: true,
                                                             wifiIPAddress: $wifiIPAddress)) {
                Text("Search by WIFI")
            }
            
            //*** MFi
            // This one uses Apple's EAAccessoryManager
            NavigationLink(destination:
                            BluetoothSearchResultView_EAAccessory(printersToSearch: SupportedModels.getArrayOfAllSupportedMFiModels(),
                                                                              mfiSerialNumber: $mfiSerialNumber)) {
                Text("Search by Bluetooth MFi (EAAccessoryManager)")
            }
            // This one uses SDK's BRPtouchBluetoothManager
            NavigationLink(destination:
                            BluetoothSearchResultView_BRPtouchBluetoothManager(printersToSearch: SupportedModels.getArrayOfAllSupportedMFiModels(),
                                                                               mfiSerialNumber: $mfiSerialNumber)) {
                Text("Search by Bluetooth MFi (BRPtouchBluetoothManager)")
            }
            
            //*** BLE
            NavigationLink(destination:
                            BLESearchResultView(printersToSearch: SupportedModels.getArrayOfAllSupportedBLEModels(),
                                                            doSearchOnAppear: true,
                                                            bleLocalName: $bleLocalName)) {
                Text("Search by Bluetooth Low Energy")
            }
            
        } // list
        .navigationBarTitle(Text("Printer Search"), displayMode: .inline)
        
    } // body
    
} // struct view

#if DEBUG
struct PrinterSearchTop_Previews: PreviewProvider {
    static var previews: some View {
        PrinterSearchTopView()
    }
} // preview
#endif
